import java.util.Scanner;

/**
 * This class implements the user interface for the coin game
 * @author alchambers
 * @version sp19
 */
public class Controller{

    // Prints a welcome message (could also print instructions)
    private static void printWelcomeMessage(){
        System.out.println("!!!!! Welcome to the coin game !!!!!");
    }

    // Returns true if the input is either "left" or "right" and false otherwise
    private static boolean validChoice(String input){
        return input.equalsIgnoreCase("left") || input.equalsIgnoreCase("right");
    }

    // displays the coin strip and prompts the user to choose either "left" or "right"
    private static String getUsersChoice(CoinGame game, Scanner scan){
        System.out.println();
        System.out.println("=============================");
        System.out.println("Gameboard: ");
        System.out.println(game.toString());
        System.out.println();

        // This loop continues until the user types a valid choice
        String choice = ""; 
        while(!validChoice(choice)){
            System.out.print("Type \"left\" or \"right\": ");
            choice = scan.nextLine();                     
        }
        return choice;
    }

    // prints the current score of the game
    private static void printScore(CoinGame game){
        System.out.println("Player 1: " + game.total(0) + " points");
        System.out.println("Player 2: " + game.total(1) + " points");
        System.out.println();
    }
    
    public static void main(String[] args){
        printWelcomeMessage();  
        
        CoinGame game = new CoinGame(10);
        Scanner scan = new Scanner(System.in);

        int player = 0; // switches between 0 and 1
        int numTurns = 10;

        while(numTurns > 0){
            String choice = getUsersChoice(game, scan);
            game.chooseCoin(choice, player);
            printScore(game);
            
            if(player == 0){
                player = 1;
            }
            else{
                player = 0;
            }
            numTurns--;
        }

        // Game over
        System.out.println();
        System.out.println("The game is over! Here are the final results: ");
        printScore(game);
    }
}
